Correct tense of ServerCall.Listener.onCompleted().

The rest of the methods are present tense, so onComplete() is more
appropriate than onCompleted().
-------------
Created by MOE: http://code.google.com/p/moe-java
MOE_MIGRATED_REVID=74703245
diff --git a/core/src/main/java/com/google/net/stubby/ServerCall.java b/core/src/main/java/com/google/net/stubby/ServerCall.java
index bf4daae..043b249 100644
--- a/core/src/main/java/com/google/net/stubby/ServerCall.java
+++ b/core/src/main/java/com/google/net/stubby/ServerCall.java
@@ -70,7 +70,7 @@
      *
      * <p>There will be no further callbacks for the call.
      */
-    public abstract void onCompleted();
+    public abstract void onComplete();
   }
 
   /**
@@ -78,7 +78,7 @@
    * status} is not equal to {@link Status#OK}, then the call is said to have failed.
    *
    * <p>If {@code status} is not {@link Status#CANCELLED} and no errors or cancellations are known
    * to have occured, then a {@link Listener#onCompleted} notification should be expected.
    * Otherwise {@link Listener#onCancel} has been or will be called.
    *
    * @throws IllegalStateException if call is already {@code close}d
@@ -78,7 +78,7 @@
    *
    * <p>If {@code status} is not {@link Status#CANCELLED} and no errors or cancellations are known
-   * to have occured, then a {@link Listener#onCompleted} notification should be expected.
+   * to have occured, then a {@link Listener#onComplete} notification should be expected.
    * Otherwise {@link Listener#onCancel} has been or will be called.
    *